@@ -1,10 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "parse-it" "0.2.1"
+(define-package "parse-it" "20260101.602"
   "Basic Parser in Emacs Lisp."
   '((emacs "25.1")
     (s     "1.12.0"))
   :url "https://github.com/jcs-elpa/parse-it"
-  :commit "f910af3b1d98b88a0f41794bbe7fd57411e9b909"
-  :revdesc "f910af3b1d98"
+  :commit "d65d74f4d057b0c7754424065c2e796dc0f89f6e"
+  :revdesc "d65d74f4d057"
+  :keywords '("convenience" "parse" "parser" "lex" "lexer" "ast")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
